@@ -46,7 +46,7 @@ public:
     /**
      * Destroys the core object.
      */
-    virtual ~Core();
+    ~Core() override;
 
     /**
      * Selects the given plugin and raises the associated part.
@@ -111,9 +111,6 @@ private:
     //@cond PRIVATE
     class Private;
     Private *const d;
-
-    Q_PRIVATE_SLOT(d, void slotPartDestroyed(QObject *))
-    Q_PRIVATE_SLOT(d, void checkNewDay())
     //@endcond
 };
 
